Module parser

Module parser 

Re-exports

pub use crate::code_unit::CodeUnit;
pub use crate::code_unit::CodeUnitKind;

Functions

has_cfg_test_attr
Check if attributes contain #[cfg(test)].
has_test_attr
Check if attributes contain #[test].
parse_file
Parse a single Rust file and extract code units.
parse_files
Parse multiple files and collect all code units, skipping files that fail to parse.
parse_source
Parse Rust source code and extract code units.