Re-exports
pub use crate::code_unit::CodeUnit;pub use crate::code_unit::CodeUnitKind;
Functions
- has_
cfg_ test_ attr - Check if attributes contain
#[cfg(test)]. - has_
test_ attr - Check if attributes contain
#[test]. - parse_
file - Parse a single Rust file and extract code units.
- parse_
files - Parse multiple files and collect all code units, skipping files that fail to parse.
- parse_
source - Parse Rust source code and extract code units.